FolderNode

Struct FolderNode 

pub struct FolderNode {
    pub name: String,
    pub parent: Option<Arc<Mutex<FolderNode>>>,
    pub children: Vec<Node>,
    /* private fields */
}
Represents a folder in the file system.

Fields

name: String

The name of the folder

parent: Option<Arc<Mutex<FolderNode>>>

The parent of the folder

children: Vec<Node>

The children of the folder

Implementations

Source

impl FolderNode

pub fn new( name: String, entry: SgaFolderEntry, parent: Option<Arc<Mutex<FolderNode>>>, children: Option<Vec<Node>>, ) -> Self

Construct a new FolderNode

pub fn add_child(&mut self, node: Node)

Add a child to the folder

pub fn read_files_from_folder<T: Read + BufRead + Seek>( this: Arc<Mutex<Self>>, reader: &mut T, entries: &SgaEntries, ) -> Result<Vec<FileNode>>

Reads all the files from the folder Kinda annoying, but since we can’t do arbitrary self types in rust, you must pass this instead.

pub fn read_folders_from_folder<T: Read + BufRead + Seek>( this: Arc<Mutex<Self>>, reader: &mut T, entries: &SgaEntries, ) -> Result<Vec<FolderNode>>

Reads all the folders from the specified folder Kinda annoying, but since we can’t do arbitrary self types in rust, you must pass this instead.

pub fn folder_from_entry<T: Read + BufRead + Seek>( reader: &mut T, entries: &SgaEntries, folder_entry: &SgaFolderEntry, parent: Option<Arc<Mutex<FolderNode>>>, ) -> Result<Self>

Constructs a folder from an entry